#!/bin/sh
# Copyright(c) Sybase, Inc.
#
# Command-line options:
# 1) -port <port> or -p <port>
#    to change RMI port number.
# 2) -message <level> or -m <level>
#    to change message level,
#    where valid value of message level is: 
#    {OFF | FATAL | ERROR | WARN | INFO | DEBUG}
# 3) -v or -version
#    to display agent version information
#

if [ -z "${SYBASE_UA}" ]; then
    echo The environment variable SYBASE_UA must be defined.
    echo This directory contains the UAF bin, common, conf, ..etc. directories.
    exit 1
fi

if [ ! -d ${SYBASE_UA}/bin ]; then
    echo The directory defined by the environment variable SYBASE_UA = ${SYBASE_UA}.
    echo Does not contain a bin directory.  Please check and make sure the enviromnet
    echo has been set properly.
    exit 1;
fi

if [ ! -x ${SYBASE_UA}/bin/myenv ]; then
    echo The file "myenv" was not found in the ${SYBASE_UA}/bin directory.
    echo Please check the assignment of the SYBASE_UA environment variable.
    exit 1
fi

. ${SYBASE_UA}/bin/myenv

if [ ${UA_ENV_STATUS} -eq 1 ]; then
  echo Failed to properly initialize environment variables
  exit 1
fi

# processing command-line options
ARGS=$@
displayVersion=0;
messageLevel=WARN;
while [ ! "$1" = "" ]; do
    case $1 in 
      -v | -version | -V | -VERSION) 
         displayVersion=1;
         ;;
      -m | -message) 
         messageLevel=$2
         shift 
         ;;
      -p | -port) 
         port=$2
         shift
       ;;
    esac
    shift
done

# handle displayVersion
if [ $displayVersion -eq 1 ]; then

  ${SYBASE_JRE}/bin/java $bitwidth -classpath ${SYBASE_UA}/server/lib/uaf-util.jar com.sybase.ua.util.JarInfo -jar ${SYBASE_UA}/common/lib/uaf-server.jar

  exit 0
fi

echo Node: $nodename
echo Operating System: $osname
echo OS Architecture: $osarch
echo OS Version: $osversion
echo JAVA Runtime: $SYBASE_JRE
${SYBASE_JRE}/bin/java -version

echo Message level: $messageLevel
if [ $port ]; then
  echo RMI port: $port
fi

if [ ! -x ${SYBASE_UA}/bin/multinode ]; then
    echo The file "multinode" was not found in the ${SYBASE_UA}/bin directory.
    echo Please check the assignment of the SYBASE_UA environment variable.
    exit 1
fi

. ${SYBASE_UA}/bin/multinode


# create UAF log directory if not exist
if [ ! -d ${SYBASE_UA}/log ]; then
  mkdir ${SYBASE_UA}/log
fi

# handle RMI port
if [ $port ]; then

  echo Changing RMI port to $port...
  echo Updating $SYBASE_UA/services/RMI/service-config.xml...
  
  ${SYBASE_JRE}/bin/java -Dcom.sybase.ua.log.level=$messageLevel \
    -Dcom.sybase.ua.home="${SYBASE_UA}" \
    -classpath ${SYBASE_UA}/common/lib/uaf-client.jar:${SYBASE_UA}/common/lib/uaf-server.jar:${SYBASE_UA}/common/lib/commons-logging.jar:${SYBASE_UA}/common/lib/log4j-1.2.6.jar:${SYBASE_UA}/common/lib/commons-digester.jar:${SYBASE_UA}/common/lib/commons-collections.jar:${SYBASE_UA}/common/lib/commons-beanutils.jar:${SYBASE_UA}/common/lib/jdom.jar \
    com.sybase.ua.config.AgentServicePropertyWriter $SYBASE_UA/services/RMI port $port
fi

#
# startup the agent
#
# To set VM's max heap size, insert "-Xmx<size>" after the java command. e.g., -Xmx500M
# To set VM's initial heap size, insert "-Xms<size>" after the java command. e.g., -Xms200M
#
  ${SYBASE_JRE}/bin/java $bitwidth -Djava.library.path="${SYBASE_UA}/rtlib" \
  -Dcom.sybase.ua.log.level=$messageLevel \
  -Djava.security.policy=${POLICY} \
  -Dcom.sybase.home="${SYBASE}" \
  -Dcom.sybase.ua.toplevel="${SYBASE_UA_TOPLEVEL}" \
  -Dcom.sybase.ua.home="${SYBASE_UA}" \
  -classpath ${SYBASE_UA}/server/lib/uaf-startup.jar \
  com.sybase.ua.startup.Startup $ARGS

