// This sample code collects input from the command line and
// invokes the execute web method provided by ASE Web Services Producer.

using System;

namespace Execute
{
	class Execute
	{
		[STAThread]
		static void Main(string[] args)
		{
			Console.WriteLine ("ExecuteSelect Initiating Execution \n");

			// Verify number of arguments. Nothing fancy here.
			if (args.Length != 8)
			{
				Console.WriteLine ("Gotta have 8 args: ");
				Console.WriteLine ("Arg1: SOAP Endpoint eg. http://nnebbish:8181/services/ase");
				Console.WriteLine ("Arg2: ASE Service Name ");
				Console.WriteLine ("Arg3: ASE Username");
				Console.WriteLine ("Arg4: ASE Password");
				Console.WriteLine ("Arg5: SQLX Options");
				Console.WriteLine ("Arg6: Dataoutput (one of all, data, schema, or dtd)");
				Console.WriteLine ("Arg7: Number of times to execute");
				Console.WriteLine ("Arg8: Sql Query");

				Environment.Exit (0);				
			}

			// Now that we have the right number of args, we ASSUME that all the types
			// are also correct by gathering them.

			string soapurl = args[0];
			string aseService = args[1];
			string aseUserName = args[2];
			string asePassword = args[3];
			string sqlxOptions = args[4];
			string dataoutput = args[5];
			int numIterations = int.Parse(args[6]);
			string sqlQuery = args[7];

			Console.WriteLine ("Echoing Arguments: ");
			Console.WriteLine ("SOAP Endpoint:   " + soapurl);
			Console.WriteLine ("ASE Service:   " + aseService);
			Console.WriteLine ("ASE Username:    " + aseUserName);
			Console.WriteLine ("ASE Password:    [*************]");
			Console.WriteLine ("Sql Query:       [" + sqlQuery + "]");
			Console.WriteLine ("SQLX Options:    [" + sqlxOptions + "]");
			Console.WriteLine ("Setting number of iterations to 1");
			Console.WriteLine ("Dataoutput:      " + dataoutput);

			// We have created WebReference1 using the "Add Web Reference" command in the
			// Project menu pulldown.

			WebReference1.DataReturn[] data;
			WebReference1.ExecuteStoredProcService ase = new WebReference1.ExecuteStoredProcService();

			// We specify the SOAP Endpoint and override whatever is in
			// the generated proxy code. This is done so that we can choose
			// which ASE to send SOAP messages to.

			ase.Url = soapurl;

			// Execute the web method.

			data = ase.execute (aseService,  
				aseUserName, 
				asePassword, 
				sqlxOptions,
				sqlQuery);
				
			// If we really have data, print it out.

			if (data != null)
			{
				for (int ii = 0; ii < data.Length; ii++)
				{
					if (dataoutput.CompareTo ("all") == 0 ||
						dataoutput.CompareTo ("dtd") == 0)
					{
						Console.WriteLine ("DTD: ");
						Console.WriteLine (data[ii].DTD);
					}

					if (dataoutput.CompareTo ("all") == 0 ||
						dataoutput.CompareTo ("schema") == 0)
					{
						Console.WriteLine ("Schema: " );
						Console.WriteLine (data[ii].schema);
					}
					if (dataoutput.CompareTo ("all") == 0 ||
						dataoutput.CompareTo ("data") == 0)
					{
						Console.WriteLine ("Data:" );
						Console.WriteLine (data[ii].XML);
					}
				}
			}
			else
			{
				Console.Write ("Got null data from executeSelect");
			}
			Console.WriteLine ("ExecuteSelect Terminating Execution \n");
		}
	}
}
