#!/bin/sh
# ----------------------------------------------------------------------
# @(#)scjview.sh		11/27/2007		    Sybase, Inc.
# ----------------------------------------------------------------------
# Unix/Linux launch script for Sybase Central 6.0
# ----------------------------------------------------------------------
# Copyright (c) 1995 - 2008 Sybase, Inc.  All rights reserved. 
# Unpublished rights reserved under U.S. copyright laws. This software 
# contains confidential and trade secret information of Sybase, Inc.  
# Use, duplication or disclosure of the software and documentation by 
# the U.S. Government is subject to restrictions set forth in a license 
# agreement between the Government and Sybase, Inc. or other written 
# agreement specifying the Government's rights to use the software and 
# any applicable FAR provisions, for example, FAR 52.227-19.
# ======================================================================
# CUSTOMIZE LOOK AND FEEL:
#     If you prefer a different look and feel to Sybase Central, you 
#     are welcome to uncomment one of the following settings, or add 
#     the variable 'SCJ_LAF' in your environment.
#
# (Windows only)
# SCJ_LAF=-Dswing.defaultlaf=com.sun.java.swing.plaf.windows.WindowsLookAndFeel
# (Mac only)
# SCJ_LAF=-Dswing.defaultlaf=javax.swing.plaf.mac.MacLookAndFeel
#
# (Multi Platform)
# SCJ_LAF=-Dswing.defaultlaf=javax.swing.plaf.metal.MetalLookAndFeel
# SCJ_LAF=-Dswing.defaultlaf=com.sun.java.swing.plaf.motif.MotifLookAndFeel
# ======================================================================

set +u

OS_TYPE=`uname -s`
OS_CHIP=`uname -m`

[ "$OS_TYPE" = "Linux" ] && alias echo='echo -e'	# linux uses bash

# ----------------------------------------------------------------------
# Error occured, display a message and exit
# ----------------------------------------------------------------------

Error()
{
case "$1" in
	ERR_INV_ENV_DIR)
		MSG_1="The variable $2 is not set to a valid directory."
		MSG_2="$2=$3"
		;;
	ERR_NO_JAR_FILE)
		MSG_1="Unable to locate required JAR file."
		MSG_2="Missing: $2"
		;;
	ERR_NO_JAVA)	
		MSG_1="Unable to locate the Java Runtime Environment (\$SYBASE_JRE6)."
		MSG_2="The directory $2 is missing or invalid."
		;;
	ERR_NO_IQ_ODBC)
		MSG_1="Unable to locate the Sybase IQ ODBC libraries"
		MSG_2="The library $2 is missing or invalid."
		;;
	*)
		MSG_1="Script Error:"
		MSG_2="Unable to display error message '$1'."
		;;
esac

echo ""
echo "Error: $MSG_1"
echo "       $MSG_2" 
echo ""
exit 1
}

# ----------------------------------------------------------------------
# Debugging feature.  Display the JRE version that would have run
# and create a batch file that can be run seperatly for debugging 
# ----------------------------------------------------------------------

DebugJavaCmdLine()
{
BATCH_FILE="scjview.batch"

# If the first parameter is the bit-size (-d32/-d64) add to verison display

if expr ".$2" : ".-d[63]" >/dev/null 2>&1 
then	eval $1 $2 -version
else	eval $1 -version
fi

TAB="\n"
for PARM in "$@"
do
	echo "${TAB}${PARM}\c"	
	TAB='	\\\n	'
done >	  $BATCH_FILE
chmod 755 $BATCH_FILE
cat	  $BATCH_FILE

echo "\n\n$BATCH_FILE created.\n"
}

# ======================================================================
# 				MAIN 
# ======================================================================

# Shell can be called with -debug or -batch which will cause the 
# the script to display the JRE version, runline and create a batch file. 

if [ ".$1" = ".-batch" -o ".$1" = ".-debug" ]
then	BATCH_DEBUG="Y"	; shift	; echo ""
else	BATCH_DEBUG=""
fi

# ... User params might expand "a b" to "a" "b", wrap in '' .......

USR_PARM_LIST=""

for PARM in "$@"
do
	USR_PARM_LIST="$USR_PARM_LIST '$PARM'"
done	

# ... Verify Sybase Central Directory ........................

[ -z "$SYBROOT" ] && SYBROOT="$SYBASE"

SCSHARE="$SYBROOT/shared"

SCROOT60="$SCSHARE/sybcentral600"		# must be exported to jar
export SCROOT60			

[ -d "$SYBROOT"	] || Error ERR_INV_ENV_DIR "\$SYBROOT" "$SYBROOT"
[ -d "$SCROOT60"	] || Error ERR_INV_ENV_DIR  "\$SCROOT60"  "$SCROOT60"

# ... Find Java Home and Setup environment ...................

JRE_DIR=jre-6_0	

for DIR in	"$SYBASE_JRE6"		 	\
		"$SYBROOT/$JRE_DIR" 		\
		"$SYBROOT/shared/$JRE_DIR" 	\
		"$SYBROOT/shared/sun/$JRE_DIR"	\
		"$SYBASE/$JRE_DIR" 	\
		"$SYBASE/shared/$JRE_DIR" 	\
		"$SYBASE/shared/sun/$JRE_DIR"	\
		""
do
	[ -n "$DIR" -a -x "$DIR/bin/java" ] && break;
done

[ -n "$DIR" ] ||  Error ERR_NO_JAVA "\$SYBROOT[/shared]/$JRE_DIR"

JAVA_HOME="$DIR" ; export JAVA_HOME

# ... Set the JRE flag (-d32/-64) to match the O/S bitsize ....

JAVA_BIT_SIZE=""	# Only HP and Sun (Sparc) are selectable

case "$OS_TYPE.$OS_CHIP" in
	HP-UX*)		
			JAVA_BIT_SIZE="-d`getconf KERNEL_BITS`"
			;;
	SunOS*)
			type isainfo > /dev/null 2>&1 && \
				isainfo -v | grep "^64" > /dev/null && \
					JAVA_BIT_SIZE="-d64"
			;;
esac

# ... Default parameters for the Java cmd line ...............

SCSHARE_HELP=$SCSHARE/JavaHelp-2_0
SCSHARE_JAVA=$SCSHARE/java

JAVA_PARMS="
	-Xms50m
	-Xmx500m
        -DSYBROOT='$SYBROOT'
        -DSCROOT60='$SCROOT60'
	$SCJ_LAF
	"

JAVA_JAR_LIST="
	$SCROOT60/scvwen600.jar
	$SCROOT60/sybasecentral600.jar
	
	$SCSHARE_JAVA/SCEditor600.jar
	$SCSHARE_JAVA/jsyblib600.jar

	$SCSHARE_HELP/jh.jar
	"

JAVA_RUN_PARMS="
	-screpository='$SCROOT60'
	-installdir='$SCROOT60'
	"
# ----------------------------------------------------------------------
# Each Sybase product that requires special flags for the JRE will 
# have a section below.  The section will only be called, if their
# plugin is loaded in the SCJ repository file.
# ----------------------------------------------------------------------

# Copy plugin list to a temp file then sort and reverse slashes. 

PLUGIN_LIST=/tmp/.scj.$$

egrep "^Provid.*/Classpath=" $SCROOT60/.scRepository600 2>/dev/null |
sed 's?\\\_?/?g' |
sort > $PLUGIN_LIST

# ... If ASE plugin present ......................................

if egrep "/ASE1[2-9]." $PLUGIN_LIST >/dev/null 2>&1 
then
	JAVA_PARMS="
		$JAVA_PARMS
		-Djava.security.policy='$SCROOT60/SybaseCentral.policy'
		"
	# check native lib dir
	if [ ! -d $SCSHARE/lib64 ]
	then
		JAVA_BIT_SIZE="-d32"
		LD_LIBRARY_PATH="$SCSHARE/lib32:$LD_LIBRARY_PATH"
	else
		LD_LIBRARY_PATH="$SCSHARE/lib64:$SCSHARE/lib32:$LD_LIBRARY_PATH"
		LD_LIBRARY_PATH_64="$SCSHARE/lib64:$LD_LIBRARY_PATH_64"
		export LD_LIBRARY_PATH_64
	fi
	export LD_LIBRARY_PATH

	if [ "$OS_TYPE" = AIX ]
	then
		LIBPATH="$SCSHARE/lib64:$SCSHARE/lib32:$LIBPATH"
		export LIBPATH
	fi
fi

# ... If Sybase IQ or SA plugin present ..........................

if egrep "/IQ1[2-9]|/SA1" $PLUGIN_LIST >/dev/null 2>&1 
then
	# Find the IQ/SA install directory, based on the plugin location

	INST_DIR=`egrep "/IQ1|/SA1" $PLUGIN_LIST |tail -1 |cut -f2 -d=`
	INST_DIR=`dirname "$INST_DIR"`
	INST_DIR=`dirname "$INST_DIR"`

	set -- `ls -1 $INST_DIR/lib*/libdbodbc*_r.s? 2>/dev/null` 

	[ -z "$1" ] && Error ERR_NO_IQ_ODBC "$INST_DIR/lib/libdbodbc*_r.s?"

	JAVA_PARMS="
		$JAVA_PARMS
		-Dasa.location='$INST_DIR'
		-Dsybase.asa.logon.odbcdriver='$1'
		"

	# Add in the required libraries to libpath

	set -- `ls -d1 $INST_DIR/lib* $SCSHARE/lib*`

	SCJ_LIBPATH=`echo $@ | sed 's? ?:?g'`

	case "$OS_TYPE" in
		AIX)	LIBPATH="$LIBPATH:$SCJ_LIBPATH"
			export LIBPATH
			;;
		*)	LD_LIBRARY_PATH="$LD_LIBRARY_PATH:$SCJ_LIBPATH"
			export LD_LIBRARY_PATH
			;;
	esac
fi

# ... If RepServer plugin present .................................
#
# etc...
#

rm -f $PLUGIN_LIST	# Remove temp plugin file

# ----------------------------------------------------------------------
# Start sybase central
# ----------------------------------------------------------------------

# ... Create class path ......................................

CLASSPATH=""

for JAR_FILE in $JAVA_JAR_LIST
do
	[ -s $JAR_FILE ] || Error ERR_NO_JAR_FILE "$JAR_FILE"

	CLASSPATH="${CLASSPATH}${JAR_FILE}:"
done

# ... Run or debug it ........................................

eval set --	$JAVA_HOME/bin/java			\
		$JAVA_BIT_SIZE				\
		$JAVA_PARMS				\
		-classpath "$CLASSPATH"			\
		com.sybase.central.viewer.SybaseCentral	\
		$JAVA_RUN_PARMS				\
		$USR_PARM_LIST

if [ "$BATCH_DEBUG" = "Y" ]
then
	DebugJavaCmdLine "$@"
else
	echo ""

	exec "$@" 
fi

# -- eof --

